<?php

namespace Drupal\menu_block_settings_override\Plugin\Field;

use Drupal\Core\Access\AccessResult;
use Drupal\Core\Field\FieldItemList;
use Drupal\Core\Form\FormStateInterface;
use Drupal\Core\Session\AccountInterface;

/**
 * Defines a item list class for menu block settings override fields.
 */
class MenuBlockSettingsOverrideFieldItemList extends FieldItemList {

  /**
   * {@inheritdoc}
   */
  public function defaultValuesForm(array &$form, FormStateInterface $form_state) {
    // We don't want to use any default values form.
  }

  /**
   * {@inheritdoc}
   */
  public function defaultAccess($operation = 'view', AccountInterface $account = NULL) {
    if ($operation === 'edit') {
      return AccessResult::allowedIfHasPermission($account, 'override menu block settings');
    }
    return parent::defaultAccess($operation, $account);
  }

  /**
   * {@inheritdoc}
   */
  public static function isApplicable(FieldDefinitionInterface $field_definition) {
    return ($field_definition->getFieldStorageDefinition()->getSetting('target_type') == 'node');
  }

  /**
   * @param string $menu_block_id
   * @return bool|MenuBlockSettingsOverrideItem
   */
  public function getValueForMenuBlockId($menu_block_id) {
    $matches = array_filter($this->list, function ($item) use ($menu_block_id) {
      return $item->get('menu_block_id')->getValue() === $menu_block_id;
    });
    return !empty($matches) ? $matches[0] : FALSE;
  }

}
